@@ -1,5 +1,5 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/MakeHelper.pm,v 1.35 2006/01/29 04:43:08 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/MakeHelper.pm,v 1.36.2.1 2007/02/24 14:14:35 kaffeetisch Exp $
 #
 
 package Glib::MakeHelper;
@@ -374,17 +374,29 @@ sub postamble_docs_full {
 	# lib file to be created. the following trick is intended to handle
 	# both of those cases without causing the other to happen.
 	my $blib_done;
+
 	# this is very sloppy, because different makes have different
-	# conditional syntaxes.
-	use Config;
-	if ($Config{make} eq 'nmake') {
-		warn "loathe nmake.\n";
+	# conditional syntaxes.  we support three brands: nmake, BSD make, and
+	# GNU make.  On Windows, we use nmake.  On BSD we use BSD make unless
+	# the environment variable FORCE_GMAKE is set, in which case we use
+	# gmake.  Everywhere else, we use gmake.
+	require Config;
+	if ($Config::Config{make} eq 'nmake') {
 		$blib_done = "
 !If \"\$(LINKTYPE)\" == \"dynamic\"
 BLIB_DONE=\$(INST_DYNAMIC)
 !ELSE
 BLIB_DONE=\$(INST_STATIC)
 !ENDIF
+";
+	} elsif ($^O =~ m{^(freebsd|netbsd|openbsd)$}i && !$ENV{FORCE_GMAKE}) {
+		warn "Defaulting to BSD make; set FORCE_GMAKE if you want GNU make\n";
+		$blib_done = "
+.if \$(LINKTYPE) == dynamic
+BLIB_DONE=\$(INST_DYNAMIC)
+.else
+BLIB_DONE=\$(INST_STATIC)
+.endif
 ";
 	} else {
 		# assuming GNU Make
@@ -509,10 +521,9 @@ inserted by this module under the name MY::const_cccmd to fix this issue.
 sub const_cccmd {
 	my $inherited = shift->SUPER::const_cccmd (@_);
 	return '' unless $inherited;
-	use Config;
+	require Config;
 	# a more sophisticated match may be necessary, but this works for me.
-	if ($Config{cc} eq "cl") {
-		warn "you are using MSVC... my condolences.\n";
+	if ($Config::Config{cc} eq "cl") {
 		$inherited .= ' /Fo$@';
 	} else {
 		$inherited .= ' -o $@';
