@@ -16,7 +16,7 @@
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.44.2.1 2006/11/19 19:24:46 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.44.2.2 2006/11/23 18:45:21 kaffeetisch Exp $
  */
 
 #ifndef _GPERL_H_
@@ -26,7 +26,7 @@
 #include "perl.h"
 #include "XSUB.h"
 
-#ifdef G_OS_WIN32
+#ifdef WIN32
   /* perl and glib disagree on a few macros... let the wookie win. */
 # undef pipe
 # undef malloc
